@@ -37,7 +37,7 @@ class baseWebBrowserController:
         self.cbCreateSearchResultDictionaryByBeutifulSoup = baseWebBrowserController.createSearchResultDictionaryByBeutifulSoup
         self.cbCreateSearchResultDataFrameByWebDriver = baseWebBrowserController.createSearchResultDataFrameByWebDriver
         self.cbCreateSearchResultDataFrameByBeutifulSoup = baseWebBrowserController.createSearchResultDataFrameByBeutifulSoup
-            
+                
     @Logger.loggerDecorator('Get WebDriverPath')
     def getWebDriverPath(self, _webDriverPath:scrapingConfig.settingValueStruct.WebDriverPath):
         
@@ -176,18 +176,36 @@ class baseWebBrowserController:
         locater : str
             By.ID,By.CSS_SELECTOR,By.CLASS_NAME,By.TAG_NAME
         """
+
+        # データ作成前処理
+        self.createSearchResultDataFrameBeforeProc(*args, **kwargs)
         
+        # データ作成処理
+        retDataFrame = None
         if self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.selenium.value:
             # 待機
             element = self.WebDriverWait(locater)
             # スクレイピング
-            return self.cbCreateSearchResultDataFrameByWebDriver(element, *args, **kwargs)
+            retDataFrame = self.cbCreateSearchResultDataFrameByWebDriver(element, *args, **kwargs)
         elif self.config.ScrapingType == self.config.settingValueStruct.ScrapingType.beutifulSoup.value:
             # 待機
             self.Delay()
             # スクレイピング
-            return self.cbCreateSearchResultDataFrameByBeutifulSoup(self.bSoup, *args, **kwargs)
+            retDataFrame = self.cbCreateSearchResultDataFrameByBeutifulSoup(self.bSoup, *args, **kwargs)
 
+        # データ作成後処理
+        self.createSearchResultDataFrameAfterProc(*args, **kwargs)
+        
+        return retDataFrame
+
+    @Logger.loggerDecorator('Create SearchResultDataFrame - BeforeProc')    
+    def createSearchResultDataFrameBeforeProc(self, *args, **kwargs):
+        pass
+
+    @Logger.loggerDecorator('Create SearchResultDataFrame - AfterProc')    
+    def createSearchResultDataFrameAfterProc(self, *args, **kwargs):
+        pass
+    
     @Logger.loggerDecorator('Create SearchResultDataFrame By WebDriver')
     def createSearchResultDataFrameByWebDriver(self, element, *args, **kwargs) -> DataFrame:
 
